<?php

/*管理ページのカスタマイズ
---------------------------------------------------------------------------------------------------------*/
function my_theme_support(){

	//アイキャッチ画像を使う
	add_theme_support('post-thumbnails');
	
	//カスタムヘッダーを使う
	add_theme_support('custom-header', array(
		'flex-width' => true,
		'width' => '2500',
		'flex-height' => true,
		'height' => '700',
		'default-image' => '%s/images/mainimg.jpg',
	));
	
	//カスタムメニューを使う
	register_nav_menus(array(
		'main-menu' => 'メインメニュー',
		'main-menu-s' => '小さな端末用メインメニュー',
		'sub-menu' => 'サブメニュー',
		'footer-menu' => 'フッターメニュー',
	));

}
add_action('after_setup_theme', 'my_theme_support');



/*ウィジェットを使う（管理画面の「外観」->「ウィジェット」で利用できます）
---------------------------------------------------------------------------------------------------------*/
function my_sidebar(){

	register_sidebar(array(
		'id' => 'sidebar',
		'name' => 'サイドバーウィジェット',
		'description' => 'サブコンテンツに表示するウィジェットです',
		'before_widget' => '<div class="%2$s">',
		'after_widget' => '</div>',
	));

}
add_action('widgets_init', 'my_sidebar');



/*カスタム投稿タイプ
---------------------------------------------------------------------------------------------------------*/
function my_list_type(){

	//list（一覧 --> サービス一覧・メニュー一覧など）ページの設定
	register_post_type('list',array(
		'label' => '一覧ページ',	//「一覧ページ」の文字は変更して頂いて構いません。例：商品一覧、など。管理ページメニューに表示されます。
		'public' => true,
		'menu_position' => 5,
		'menu_icon' => get_stylesheet_directory_uri() . '/images/icon_custum_menu.png',
		'supports' => array('title','editor','thumbnail','custom-fields','revision'),
		'has_archive' => true,
	));
	//list（一覧）ページのタクソノミー設定
	register_taxonomy('genre', 'list', array(
		'label' => 'ジャンル',	//「ジャンル」の文字は変更して頂いて構いません。
		'public' => true,
		'hierarchical' => true,
	));
	
	//faq（よく頂く質問）ページの設定
	register_post_type('faq',array(
		'label' => 'よく頂く質問',
		'public' => true,
		'menu_position' => 5,
		'menu_icon' => get_stylesheet_directory_uri() . '/images/icon_custum_menu.png',
		'supports' => array('title','editor','revision'),
		'has_archive' => true,
	));
	
	//link（リンク）ページの設定
	register_post_type('link',array(
		'label' => 'リンク',
		'public' => true,
		'menu_position' => 5,
		'menu_icon' => get_stylesheet_directory_uri() . '/images/icon_custum_menu.png',
		'supports' => array('title','editor','thumbnail','custom-fields','revision'),
		'has_archive' => true,
	));
	
	//blog（ブログ）ページの設定
	register_post_type('blog',array(
		'label' => 'ブログ',
		'public' => true,
		'menu_position' => 5,
		'menu_icon' => get_stylesheet_directory_uri() . '/images/icon_custum_menu.png',
		'supports' => array('title','editor','thumbnail','comments','revision'),
		'has_archive' => true,
));

}
add_action('init', 'my_list_type');



/* 自作のcssファイルとjsファイルを読み込む 
---------------------------------------------------------------------------------------------------------*/
function my_enqueue(){

	wp_enqueue_script('myjs1', get_stylesheet_directory_uri() . '/js/openclose.js');	//jsフォルダのopenclose.jsの読み込み
	wp_enqueue_style('mystyle1', get_stylesheet_directory_uri() . '/css/style.css');	//cssフォルダのstyle.cssの読み込み
	wp_enqueue_style('mystyle2', get_stylesheet_directory_uri() . '/css/logo.css');		//cssフォルダのlogo.cssの読み込み

}
add_action('wp_enqueue_scripts', 'my_enqueue');



/*投稿数を出力する際、aタグの内側に（https://ja.wordpress.org/support/topic/）
---------------------------------------------------------------------------------------------------------*/
add_filter( 'wp_list_categories', 'my_list_categories', 10, 2 );
function my_list_categories( $output, $args ) {
$output = preg_replace('/<\/a>\s*\((\d+)\)/',' ($1)</a>',$output);
return $output;
}
add_filter( 'get_archives_link', 'my_archives_link' );
function my_archives_link( $output ) {
$output = preg_replace('/<\/a>\s*(&nbsp;)\((\d+)\)/',' ($2)</a>',$output);
return $output;
}